@@ -518,10 +518,7 @@ def skymap_hpx(file0, save=False, path="", name=""):
     fig, ax = projection_axes(projection=projection, figsize=[40 / 2.54, 30 / 2.54])
 
     gw_map = hp.read_map(file0)
-    hp.mollview(
-        map = gw_map,
-        fig = fig
-    )
+    hp.mollview(map=gw_map, fig=fig)
     hp.graticule()
 
     if save:
@@ -633,7 +630,7 @@ def skymap_list(
 
                 h.append(alert)
 
-        plt.legend(handles=h, bbox_to_anchor=(1.05, 1.05))
+        plt.legend(handles=h, bbox_to_anchor=(1.1, 1.2), loc="upper right")
 
     if save:
         if path != "":
@@ -800,7 +797,7 @@ def skymap_alert(
     h.append(horizon_line)
     h.append(gal_line)
 
-    plt.legend(handles=h, bbox_to_anchor=(1.05, 1.05))
+    plt.legend(handles=h, bbox_to_anchor=(1.1, 1.2), loc="upper right")
 
     if save:
         if path != "":
